@@ -2,7 +2,9 @@ use std::borrow::Cow;
 use std::ffi::OsStr;
 #[cfg(feature = "macchina")]
 use std::fs;
-use std::io::{self, Write as _};
+use std::io::{Write as _};
+#[cfg(windows)]
+use std::io::{self};
 use std::path::PathBuf;
 use std::process::Command;
 use std::sync::OnceLock;
@@ -113,16 +115,12 @@ where
         };
 
         if let Some(selected) = find_selection(&selection, options) {
-            writeln!(io::stdout()).context("failed to write to stdout")?;
+            println!();
 
             return Ok(selected);
         } else {
             let options_text = options.iter().map(AsRef::as_ref).join("|");
-            writeln!(
-                io::stdout(),
-                "Invalid selection! {selection} is not one of {options_text}"
-            )
-            .context("failed to write message to stdout")?;
+            println!("Invalid selection! {selection} is not one of {options_text}");
         }
     }
 
@@ -285,7 +283,7 @@ pub fn run(asc: RecoloredAsciiArt, backend: Backend, args: Option<&Vec<String>>)
 }
 
 /// Gets distro ascii width and height, ignoring color code.
-pub fn ascii_size<S>(asc: S) -> Result<(u8, u8)>
+pub fn ascii_size<S>(asc: S) -> Result<(u16, u16)>
 where
     S: AsRef<str>,
 {
@@ -307,25 +305,11 @@ where
         return Ok((0, 0));
     }
 
-    let width = asc
-        .lines()
-        .map(|line| line.graphemes(true).count())
-        .max()
+    let width = asc.lines()
+        .map(|line| line.graphemes(true).count()).max()
         .expect("line iterator should not be empty");
-    let width: u8 = width.try_into().with_context(|| {
-        format!(
-            "`asc` should not have more than {limit} characters per line",
-            limit = u8::MAX
-        )
-    })?;
-    let height = asc.lines().count();
-    let height: u8 = height.try_into().with_context(|| {
-        format!(
-            "`asc` should not have more than {limit} lines",
-            limit = u8::MAX
-        )
-    })?;
-
+    let width: u16 = width.try_into().context("ascii art width should fit in u16")?;
+    let height: u16 = asc.lines().count().try_into().context("ascii art height should fit in u16")?;
     Ok((width, height))
 }
 
