@@ -16,8 +16,9 @@ rm -rf build/
 # Remove git from the source code before building
 rm -rf hyfetch/git/
 
-# Build python from setup.py
-python3 setup.py sdist bdist_wheel
+# Build python package
+python3 -m pip install build
+python3 -m build
 
 # Check
 twine check dist/*.tar.gz
@@ -61,11 +62,6 @@ cp "$DIR/../target/x86_64-pc-windows-gnu/release/hyfetch.exe" wheel/hyfetch/rust
 sed -i 's/Tag: py3-none-.*/Tag: py3-none-win32/' wheel/*.dist-info/WHEEL
 python "$DIR/build_rehash.py" wheel
 
-# Zip to -win32.whl
-#new_name=${file/-any/-win32}
-#cd wheel && zip -qq -y -r "../$new_name" * && cd ..
-#twine check "$new_name"
-
 # Zip to -win_amd64.whl
 # Since pypi doesn't allow two identical files with different names to be uploaded
 # We need to change the zip content a little bit for win_amd64
@@ -78,8 +74,10 @@ twine check "$new_name"
 # =================
 # Build for linux
 
-# Now we're done with windows, delete the git folder
-rm -rf wheel/git
+# Now we're done with windows, delete wheel and unzip again
+echo "> Building for other platforms"
+rm -rf wheel
+unzip -qq "$file" -d wheel
 
 function build_for_platform() {
     ff_platform=$1
